@@ -813,9 +813,13 @@ class ProcessorParser:
                             break
 
                 for cassr in csess.assessors():
-                    if cassr.type() in iv['types']:
-                        artefacts_by_input[i].append(cassr.full_path())
-
+                    try:
+                        if cassr.type() in iv['types']:
+                            artefacts_by_input[i].append(cassr.full_path())
+                    except:
+                        # Perhaps type/proctype is missing
+                        LOGGER.error(f'Failed to add {cassr.full_label()} to processing list')
+                        
         return artefacts_by_input
 
     # TODO: BenM improve name of generate_parameter_matrix
@@ -942,17 +946,24 @@ class ProcessorParser:
 
         assessors = [[] for _ in range(len(parameter_matrix))]
 
-        for casr in [a for a in csess.assessors() if a.type() == proc_type]:
-            inputs = casr.get_inputs()
-            if inputs is None:
-                LOGGER.warn('skipping, inputs field is empty:' + casr.label())
-                return list()
+        for casr in csess.assessors():
+            try:
+                proc_type_matches = (casr.type() == proc_type)
+            except:
+                LOGGER.error(f'Failed to check type of {casr.label()}')
+                continue
+            
+            if proc_type_matches:
+                inputs = casr.get_inputs()
+                if inputs is None:
+                    LOGGER.warn(f'Empty inputs - skipping {casr.label()}')
+                    continue
 
-            for pi, p in enumerate(parameter_matrix):
-                if inputs == p:
-                    # BDB 6/5/21 do we ever have more than one assessor
-                    # with the same set of inputs?
-                    assessors[pi].append(casr)
+                for pi, p in enumerate(parameter_matrix):
+                    if inputs == p:
+                        # BDB  6/5/21 do we ever have more than one assessor
+                        #             with the same set of inputs?
+                        assessors[pi].append(casr)
 
         return list(zip(copy.deepcopy(parameter_matrix), assessors))
 
